Configuration
=============
Upon first launch, *spreads* writes a configuration file to
`~/.config/spreads/config.yaml`. In it, you can change all of the available
settings to your liking:

.. literalinclude:: ../spreads/config_default.yaml
   :language: yaml
